package org.alltimeflashdreamer.mailwebform;

/**
 * Title: MailWebFormConstants<br>
 * Description: "Storage" for all the constants used in the MailWebForm
 * application. This list is designed to be implementable for classes
 * accessing those constants frequently.
 *
 * @author Copyright (c) 2001-2005 Florian Steinsiepe, Adrian Zaugg
 * @version 0.9
 */
public interface MailWebFormConstants
{
	//------------------ application constants --------------------//

	/** often used app name (version independent) */
	public static final String MAILWEBFORM = "MailWebForm";

	/** value used for the self-identification */
	public static final String APPNAME = MAILWEBFORM + " v0.9.1";

	/**
	 * name of the Java System Property pointing to the app's config directory
	 */
	public static final String PROPERTY_CONFIGDIR = MAILWEBFORM.toLowerCase() +
		".configdir";

	/**
	 * suffix of the individual property files within the config or the
	 * provider directory
	 */
	public static final String PROPERTY_SUFFIX = ".properties";

	/**
	 * suffix of the template files within the config directory or the provider
	 * directory
	 */
	public static final String TEMPLATE_SUFFIX = ".template";

	/** beginning of a placeholder entry within a template file */
	public static final String PLACEHOLDER_START = "${";

	/** end of a placeholder entry within a template file */
	public static final String PLACEHOLDER_END = "}";

	/**
	 * the name of the global properties file which must reside in the app's
	 * config directory
	 */
	public static final String RESOURCENAME = 
		MAILWEBFORM.toLowerCase() + PROPERTY_SUFFIX;

	/**
	 * the name of the user credentials file which must reside in the app's
	 * config directory
	 */
	public static final String PASSWORDFILE = 
		MAILWEBFORM.toLowerCase() + ".credentials";

	/** name of the cookie that is written after successful login */
	public static final String COOKIENAME = 
		MAILWEBFORM.toLowerCase() + "loginstate";

	/** name of the system provider, i.e. the built-in one */
	public static final String SYSTEMPROVIDER = "system";

	/**
	 * name of the session variable that stores the name of the currently
	 * logged in user
	 */
	public static final String CURRENTUSER = "currentuser";

	//------------------ system constants --------------------//

	/** stores an easy accessible copy of the system's line separator string */
	public static final String NEWLINE = System.getProperty("line.separator");

	/** stores an easy accessible copy of the system's file separator string */
	public static final String FILESEPARATOR = System.getProperty(
			"file.separator");

	//------------- application and provider property keys ---------------//

	/** key for the SMTP host name property */
	public static final String SMTP_HOST = "SMTP_HOST";

	/** key for the SMTP port number property */
	public static final String SMTP_PORT = "SMTP_PORT";

	/**
	 * key for the property specifying the redirect address after a successful
	 * mail sending
	 */
	public static final String SUCCESS_URL = "SUCCESS_URL";

	/**
	 * key for the property specifying the redirect address after an
	 * unsuccessful mail sending
	 */
	public static final String ERROR_URL = "ERROR_URL";

	/**
	 * key for the property specifying the redirect address after a detected
	 * spam error
	 */
	public static final String SPAMERROR_URL = "SPAMERROR_URL";

	/** key for the administrator's password file properties */
	public static final String ADMIN = "ADMIN";

	/** key for the password file's user name properties */
	public static final String USERNAME = "USERNAME";

	/** key for the password file's password properties */
	public static final String PASSWORD = "PASSWORD";

	/** key start for provider-specific properties */
	public static final String MAILFORMPROVIDER = "MAILFORMPROVIDER";

	/** key for the list of currently active providers property */
	public static final String MAILFORMPROVIDERLIST = "MAILFORMPROVIDERLIST";

	/**
	 * key of the property for the location of the provider's own  property
	 * file and/or mail template
	 */
	public static final String PROVIDERDIRECTORY = "PROVIDERDIRECTORY";

	/** key for provider's to-name property */
	public static final String TONAME = "TONAME";

	/** key for provider's to-address property */
	public static final String TOADDRESS = "TOADDRESS";

	/** key for provider's template property */
	public static final String TEMPLATE = "TEMPLATE";

	/** key for provider's is-allowed-to-overwrite-the-smtp-server property */
	public static final String SMTP_ALLOWOVERWRITE = "SMTP_ALLOWOVERWRITE";

	//------------- constants used for the JSP sites ---------------//

	/** key for accessing the JSPBean instance in the session */
	public static final String JSPBEAN = "jspbean";

	/** name of the deployed MailWebFormServlet */
	public static final String MAILWEBFORMSERVLET = 
		MAILWEBFORM.toLowerCase() + "servlet";

	/** name of the deployed AdminServlet */
	public static final String ADMINSERVLET = ADMIN.toLowerCase() + "servlet";

	/** name of the login JSP site */
	public static final String SITE_LOGIN = "login.jsp";

	/** name of the app's main JSP site */
	public static final String SITE_MAIN = "main.jsp";

	/** name of the error-showing JSP site */
	public static final String SITE_ERROR = "error.jsp";

	/** name of the add-or-edit provider JSP site */
	public static final String SITE_EDIT = "edit.jsp";

	/** name of the JSP site showing the default (mail web) form */
	public static final String SITE_DEFAULTFORM = "defaultform.jsp";

	/** name of the edit provider JSP site (individual version) */
	public static final String SITE_PROVIDER = "provider.jsp";

	/** name of the change admin credentials or provider password JSP site */
	public static final String SITE_CHANGE_CREDENTIALS = "change_credentials.jsp";

	/** name of the included header HTML site */
	public static final String SITE_HEADER = "admin_tool_header.html";

	/** name of the included footer HTML site */
	public static final String SITE_FOOTER = "admin_tool_footer.html";

	//------------- (uncommented) list of URL parameters ---------------//
	public static final String PARAM_ADD = "add";
	public static final String PARAM_APPLYGLOBAL = "applyglobal";
	public static final String PARAM_APPLYINDIVIDUAL = "applyindividual";
	public static final String PARAM_CANCEL = "cancel";
	public static final String PARAM_CHANGE_CREDENTIALS = "changecredentials";
	public static final String PARAM_CREDENTIALS_ADMIN = "changeadmincredentials";
	public static final String PARAM_PASSWORD_PROVIDER = "changeproviderpwd";
	public static final String PARAM_CONFIGFILE = "configfile";
	public static final String PARAM_EDIT = "edit";
	public static final String PARAM_ERRORURL = "errorurl";
	public static final String PARAM_FROMEMAIL = "fromemail";
	public static final String PARAM_FROMNAME = "fromname";
	public static final String PARAM_PROVIDERDIRECTORY = "providerdirectory";
	public static final String PARAM_LOGIN = "login";
	public static final String PARAM_LOGOUT = "logout";
	public static final String PARAM_OVERWRITE = "allowoverwrite";
	public static final String PARAM_PASSWORD = "password";
	public static final String PARAM_PROVIDER = "provider";
	public static final String PARAM_REMOVE = "remove";
	public static final String PARAM_SMTPHOST = "smtphost";
	public static final String PARAM_SMTPPORT = "smtpport";
	public static final String PARAM_SPAMURL = "spamurl";
	public static final String PARAM_STORE = "storesettings";
	public static final String PARAM_SUBJECT = "subject";
	public static final String PARAM_SUCCESSURL = "successurl";
	public static final String PARAM_TEMPLATE = "template";
	public static final String PARAM_TEXT = "text";
	public static final String PARAM_TOADDRESS = "toaddress";
	public static final String PARAM_TONAME = "toname";
	public static final String PARAM_USERNAME = "username";
}
