package org.alltimeflashdreamer.mailwebform;

/**
 * Title: MailWebFormException<br>
 * Description: Application-specific exception, thrown if certain fail
 * conditions within the workflow are met.
 *
 * @author Copyright (c) 2001-2004 Florian Steinsiepe, Adrian Zaugg
 * @version 0.9
 */
public class MailWebFormException extends Exception
{
	private Throwable cause = null;
	
	/**
	 * Constructor simply calls the superclass' constructor using the given
	 * message.
	 *
	 * @param sMessage the message text to be shown to the client
	 */
	public MailWebFormException(String sMessage)
	{
		super(sMessage);
	}

	/**
	 * Constructor simply calls the superclass' constructor using the given
	 * message and the given exception/error.
	 *
	 * @param sMessage the message text to be shown to the client
	 * @param cause the exception or error that occurred (may be nested)
	 */
	public MailWebFormException(String sMessage, Throwable cause)
	{
		super(sMessage);
		this.cause = cause;
	}

	/**
	 * Constructor simply calls the superclass' constructor using the given
	 * exception/error.
	 *
	 * @param cause the exception or error that occurred (may be nested)
	 */
	public MailWebFormException(Throwable cause)
	{
		super();
		this.cause = cause;
	}

    /**
     * Returns the cause of this throwable or <code>null</code> if the
     * cause is nonexistent or unknown.  (The cause is the throwable that
     * caused this throwable to get thrown.)
     *
     * <p>This implementation returns the cause that was supplied via one of
     * the constructors requiring a <tt>Throwable</tt>, or that was set after
     * creation with the {@link #initCause(Throwable)} method.  While it is
     * typically unnecessary to override this method, a subclass can override
     * it to return a cause set by some other means.  This is appropriate for
     * a "legacy chained throwable" that predates the addition of chained
     * exceptions to <tt>Throwable</tt>.  Note that it is <i>not</i>
     * necessary to override any of the <tt>PrintStackTrace</tt> methods,
     * all of which invoke the <tt>getCause</tt> method to determine the
     * cause of a throwable.
     * 
     * <p>Note: This method is copied from the Exception implementation in
     * JDK 1.4 to be backwards compatible with earlier versions.<p>
     *
     * @return  the cause of this throwable or <code>null</code> if the
     *          cause is nonexistent or unknown.
     * @since 1.4
     */
    public Throwable getCause() {
        return (cause==this ? null : cause);
    }
}
